<h1>Contract types</h1>
<p>A contract type describes a contract file with the associated metadata. Furthermore, the contract type defines which generators are used when creating a contract. All contracts <span
style='font-weight:bold;text-decoration:underline'>must</span> be based on a contract type.</p>
<blockquote>
<p><span
style='font-style:italic'>Metadata and structures for an application can be preset with the help of contract types. For example, if the responsible department and a risk classification are to be preset for a service contract, this can be preset in the contract type.</span></p>
</blockquote>
<p><span class="tag_important">When a new contract is created, the contract type is copied from the configuration, including all the metadata and child structures. Administrative information, such as the stored name generator, is then evaluated by the <a
href="#!/guide/p54A6AC69_E610_48D0_B2E5_CE4E57CE809A">Create contract</a> action.</span></p>
<p>The following shows a sample structure, as well as the minimum configuration for a <span
style='font-weight:bold;font-style:italic'>service contract</span> type contract.</p>
<p>{@img img1.png}</p>
<h2>Administration</h2>
<p>You can create and edit contract templates via the contract management configuration.</p>
<p>{@img img3.png}</p>
<p>You can generate new types based on existing ones. You can also extend, delete, and edit child structures. Save any changes to the structures by clicking &quot;Save&quot;.</p>
<p>{@img img5.png}</p>
<h2>Technical implementation and manual configuration</h2>
<h3>Definition and structure</h3>
<p>Contracts are filed to <code>Administration\Business Solutions Custom\contract\Configuration\Contract types</code> in the ELO repository. Each contract type is a folder that can contain child structures. The folder content describes the subsequent template for the contract.</p>
<p>{@img img7.png}</p>
<p>Contract types are described by the keywording form and the metadata of the contract (keywording form: <span
style='font-weight:bold;font-style:italic'>Contract</span>). Conversely, this means that each contract type must contain at least the contract's master metadata. If additional index fields are required for a file type, the <span
style='font-weight:bold;font-style:italic'>Contract</span> form can be copied and expanded accordingly.</p>
<p><span class="tag_important">Contract types therefore are not restricted to the default keywording form 'File'. The <span
style='font-weight:bold;font-style:italic'>Solution Object Type (SOL_TYPE)</span> index field identifies whether an ELO object is a file. By default, this object must be labeled <span
style='font-weight:bold;font-style:italic'>CONTRACT</span> in new keywording forms.</span></p>
<p><span class="tag_warning">Here, you have to check whether a keywording form is necessary for extensions. Map fields allow you to save additional information in the form, but this data cannot be searched or indexed.</span></p>
<blockquote>
<p><span
style='font-style:italic'>If the first and last name as well as the employee number are also required for an </span><span
style='font-weight:bold;font-style:italic'>employment contract</span><span
style='font-style:italic'>, a new </span><span
style='font-weight:bold;font-style:italic'>Employee contract </span><span
style='font-style:italic'>keywording form containing at least all the index fields from the </span><span
style='font-weight:bold;font-style:italic'>Contract </span><span
style='font-style:italic'>keywording form must be created. If index fields from the </span><span
style='font-weight:bold;font-style:italic'>Contract</span><span
style='font-style:italic'> keywording form are not required, we recommend hiding them in the form design and removing the corresponding form components.</span></p>
</blockquote>
<h2>Permissions</h2>
<p>Contract types can be assigned different rights in the configuration. Generally, all users with read permissions to a contract type can also create this type of contract. This allows you to control which users are able to create what type of contracts. </p>
<p>Write permissions to the contract type should only be given to users that are also permitted to edit contract types.</p>
<blockquote>
<p><span
style='font-style:italic'>Example: Only employees from the HR department should be able to create employment contracts. Permissions for the contract type should therefore only give these users read access. Administrators are also given write permissions since they can make changes to the structure of the contract type, for example.</span></p>
</blockquote>
<p><span class="tag_important">Permissions can be used to restrict the types visible to a user. Different forms of a contract type are also possible. Since the contract type is later named in the <span
style='font-weight:bold;font-style:italic'>CONTRACT_TYPE</span> index field, multiple templates (contract types) can be realized with different presets. The following example shows a specialized contract type: <span
style='font-weight:bold'>subscription &ndash; IT magazine &ndash; annual subscription</span>.</span></p>
<p>{@img img9.png}</p>
<h2>Manual creation of a new contract type</h2>
<p>On creation, a separate folder is added for each contract type; the desired keywording form must be selected for this folder. By default, the <span
style='font-weight:bold;font-style:italic'>Contract</span> keywording form should be selected here. The folder content describes the subsequent template for the contract. Content is copied to a new contract accordingly.</p>
<p><span
style='font-weight:bold'>Step 1: Select the <code>Contract types</code> folder</span></p>
<p>Contract types can be filed to the <code>Administration\Business Solutions Custom\contract\Configuration\Contract types</code> folder as objects. First, this folder has to be selected.</p>
<p><span
style='font-weight:bold'>Step 2: Create a new folder to serve as the basis for the contract type</span></p>
<p>In the client, select the standard ELO function &quot;New folder&quot; in the ribbon. The &quot;Create new folder&quot; dialog box opens. Next, the keywording form has to be selected. If no custom keywording form was created for the contract type, the <span
style='font-weight:bold;font-style:italic'>Contract</span> form can be selected.</p>
<p><span class="tag_important">You can copy an existing type to include all information required as well as a suggestion for a child structure. In this case, you will only have to modify the the contract category, contract type, and short name.</span></p>
<p><span
style='font-weight:bold'>Step 3: Add information required for the contract</span></p>
<p>The &quot;Contract type&quot; and &quot;Contract category&quot; must be specified on the contract data tab. The short name for the file type also has to be set.</p>
<table><thead><tr><td>Field</td><td>Description</td></tr></thead><tbody><tr><td>Short name</td><td>The short name of the contract type is used in the selection dialog box when creating new contracts. The name of the new contract type should be entered here.</td></tr><tr><td>Contract type</td><td>Name of the contract type. This allows users to search for this type of contract later.</td></tr><tr><td>Contract category</td><td>Name of the contract category. This allows users to combine different contract types logically later.</td></tr></tbody></table>

<p>Step 4: Administrative information</p>
<p>On the Administration tab, the default workflow has to be entered for the <a
href="#!/guide/p54A6AC69_E610_48D0_B2E5_CE4E57CE809A">Create contract</a> action, as well as the desired contract number generator and name generator.</p>
<table><thead><tr><td>Field</td><td>Description</td></tr></thead><tbody><tr><td>Default workflow: Create contract</td><td>Technical workflow for <span
style='font-weight:bold;font-style:italic'>Create contract</span> action. Additional information can be found in the action description.</td></tr><tr><td>Name generator </td><td>The name generator for creating new contracts can be specified here. The name generator generates a unique short name for a contract.</td></tr><tr><td>Contract number generator</td><td>The generator for creating a contract number can be specified here.</td></tr></tbody></table>

<h2>Additional information</h2>
<p>The <a
href="#!/guide/p54A6AC69_E610_48D0_B2E5_CE4E57CE809A">Create contract</a> action requires a technical workflow that controls the creation of a new contract. Depending on the contract type, you may want to add custom workflows. You can do this by specifying a <span
style='font-weight:bold;font-style:italic'>Default workflow</span>.</p>
<p><span class="tag_warning">Deleting or editing a contract type does not have any effects on any contracts of this type that have already been created.</span></p>
